==> apache-linkis-1.7.0-src.tar.gz: apache-linkis-1.7.0-src/linkis-engineconn-plugins/flink/flink-shims-1.16.2/src/main/java/org/apache/linkis/engineconnplugin/flink/client/shims/SessionState.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.linkis.engineconnplugin.flink.client.shims;

import org.apache.flink.table.catalog.CatalogManager;
import org.apache.flink.table.catalog.FunctionCatalog;
import org.apache.flink.table.client.resource.ClientResourceManager;
import org.apache.flink.table.module.ModuleManager;

public class SessionState {

  public final CatalogManager catalogManager;
  public final ModuleManager moduleManager;
  public final ClientResourceManager resourceManager;
  public final FunctionCatalog functionCatalog;

  public SessionState(
      CatalogManager catalogManager,
      ModuleManager moduleManager,
      ClientResourceManager resourceManager,
      FunctionCatalog functionCatalog) {
    this.catalogManager = catalogManager;
    this.moduleManager = moduleManager;
    this.resourceManager = resourceManager;
    this.functionCatalog = functionCatalog;
  }
}

==> apache-linkis-1.8.0-src.tar.gz: apache-linkis-1.8.0-src/linkis-engineconn-plugins/flink/flink-shims-1.12.2/src/main/java/org/apache/linkis/engineconnplugin/flink/client/shims/SessionState.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.linkis.engineconnplugin.flink.client.shims;

import org.apache.flink.table.catalog.CatalogManager;
import org.apache.flink.table.catalog.FunctionCatalog;
import org.apache.flink.table.module.ModuleManager;

public class SessionState {

  public final CatalogManager catalogManager;
  public final ModuleManager moduleManager;
  public final FunctionCatalog functionCatalog;

  private SessionState(
      CatalogManager catalogManager, ModuleManager moduleManager, FunctionCatalog functionCatalog) {
    this.catalogManager = catalogManager;
    this.moduleManager = moduleManager;
    this.functionCatalog = functionCatalog;
  }

  public static SessionState of(
      CatalogManager catalogManager, ModuleManager moduleManager, FunctionCatalog functionCatalog) {
    return new SessionState(catalogManager, moduleManager, functionCatalog);
  }
}
